#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::API::GoogleAdsApiService
# state        public
#----------------------------------------------------------------------------------------
# description  Service to connect to Google Ads API services
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::API::GoogleAdsApiService;

use base DE_EPAGES::GoogleSmartShopping::API::GoogleApiClient;
use DE_EPAGES::GoogleSmartShopping::API::Constants qw (
    EPAGESJ_BASE_URI
);
use DE_EPAGES::GoogleSmartShopping::API::Tools qw ( LogGoogleSmartShopping );

use strict;


#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::GoogleSmartShopping::API::GoogleAdsApiService->new( %args );
#----------------------------------------------------------------------------------------
# description  Instantiates a new GoogleAdsApiService.
#----------------------------------------------------------------------------------------
# return       GoogleAdsApiService | object | DE_EPAGES::GoogleSmartShopping::API::GoogleAdsApiService
#========================================================================================
sub new {
    my $class = shift;
    my ( $hSettings ) = @_;

    my $self = $class->SUPER::new($hSettings);

    return $self;
}

#========================================================================================
# function     getGoogleAdsAccounts
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hResponse = $self->getGoogleAdsAccounts();
#----------------------------------------------------------------------------------------
# description  Returns GoogleAdsAccounts array, or empty array if no Ads accounts found.
#----------------------------------------------------------------------------------------
# return       $aResponse | array with Google Ads Accounts | array.ref
#========================================================================================
sub getGoogleAdsAccounts {
    my $self = shift;

    my $Url = EPAGESJ_BASE_URI . 'accounts/ads/list';
    my $Headers = {'X-DeveloperToken' => $self->_getDeveloperToken()};

    my $aResponse;

    $aResponse =  $self->doGet($Url, $Headers);
    LogGoogleSmartShopping('GoogleAdsAccounts:', $aResponse);

    return $aResponse;
}

sub _getDeveloperToken {
    my $self = shift;

    $self->loadGoogleSettings();
    return $self->{'GoogleSmartShopping_AdsDeveloperToken'};
}

1;