#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::Hooks::Attribute
# state        public
#----------------------------------------------------------------------------------------
# description  Define what attrinutes that can be configured in PBO
#----------------------------------------------------------------------------------------
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::Hooks::Attribute;

use DE_EPAGES::Object::API::Factory qw (GetRootObjectID);
use DE_EPAGES::ThirdPartyConfig::API::Constants qw (ATTRIBUTES_CATEGORY_MISC);

use strict;

#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  API_GetThirdPartyConfigAttributes triggered, register attributes to be
#               configured in PBO
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>AttributesCategory
#                   <li>LanguageID
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    return unless $hParams->{'AttributesCategory'} eq ATTRIBUTES_CATEGORY_MISC;

    my $RootObjectID = GetRootObjectID();

    push(@{$hParams->{'Attributes'}}, {
        'SectionID'   => 'GoogleSmartShopping',
        'SectionName' => 'Google Smart Shopping',
        'Attributes' => [
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_Logging'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AuthURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AuthTokenURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AppRedirectURL'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AppClientID'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AppClientSecret'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AdminRefreshToken'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AdsDeveloperToken'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_MerchantCenterMultiClientAccountID'},
            {'ObjectID' => $RootObjectID, 'AttributeAlias' => 'GoogleSmartShopping_AdsManagerAccountId'},
        ]
    });

    return;
}


1;