#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::Hooks::Servlet
# state        public
# description  Additional hook function for OnIsEp6HandledUnityRequest hook.
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::Hooks::Servlet;

use strict;

#========================================================================================
# function     OnIsEp6HandledUnityRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnIsEp6HandledUnityRequest($hParams);
#----------------------------------------------------------------------------------------
# description  Triggered by hook IsEp6HandledUnityRequest.
#               The GSS site verification should be rendered by epages6 for any Unity shop.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - servlet object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnIsEp6HandledUnityRequest {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Object'};

    # skip if another hook function already acknowledges the request as a unity request handled by epages6
    return if $hParams->{'Values'}->{'IsEp6HandledUnityRequest'};

    my $ViewAction= $Servlet->params('ViewAction');

    # redirect GoogleHTML to epages 6
    $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1
        if $ViewAction eq 'UnitySF-ViewGoogleSmartShoppingHTML';

    return;
}

1;