#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::PriceListGlobalValueDiscountsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import global value discounts.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::PriceListGlobalValueDiscountsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
use DE_EPAGES::ShopMigration::API::PriceListGlobalValueDiscountsCommon qw (GetPriceListGlobalValueDiscounts);
our @EXPORT_OK = qw(
    ExportPriceListGlobalValueDiscountsJSON
    ImportPriceListGlobalValueDiscountsJSON
);


#========================================================================================
# function     ExportPriceListGlobalValueDiscountsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportPriceListGlobalValueDiscountsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports global value discounts data to a json file.
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportPriceListGlobalValueDiscountsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListGlobalValueDiscountsHandler = __PACKAGE__->new($Shop);
    return $PriceListGlobalValueDiscountsHandler->exportJSONData($DirName, $PriceListGlobalValueDiscountsHandler->getExportItems());
}

#========================================================================================
# function     ImportPriceListGlobalValueDiscountsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportPriceListGlobalValueDiscountsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports global value discounts data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportPriceListGlobalValueDiscountsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    #Do not import GlobalValueDiscounts from Base if Prepshop does not have PriceList feature
    if ($Shop->get('IsMigrationPrepShop') && !$Shop->featureMaxValue('PriceLists')) {
        return;
    }

    my $PriceListGlobalValueDiscountsHandler = __PACKAGE__->new($Shop);
    return $PriceListGlobalValueDiscountsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    my $Shop = $self->shop();
    my $PriceListGlobalValueDiscounts = GetPriceListGlobalValueDiscounts($Shop);
    return $PriceListGlobalValueDiscounts;

}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListGlobalValueDiscountsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListGlobalValueDiscountsExportDriver';
}

1;
