#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::PriceListQuantityDiscountsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import quantity discounts.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::PriceListQuantityDiscountsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
use DE_EPAGES::ShopMigration::API::PriceListQuantityDiscountsCommon qw (
    GetPriceListQuantityDiscounts
 );
our @EXPORT_OK = qw(
    ExportPriceListQuantityDiscountsJSON
    ImportPriceListQuantityDiscountsJSON
);


#========================================================================================
# function     ExportPriceListQuantityDiscountsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportPriceListQuantityDiscountsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports quantity discounts data to a json file.
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportPriceListQuantityDiscountsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $PriceListQuantityDiscountsHandler = __PACKAGE__->new($Shop);
    return $PriceListQuantityDiscountsHandler->exportJSONData($DirName, $PriceListQuantityDiscountsHandler->getExportItems());
}

#========================================================================================
# function     ImportPriceListQuantityDiscountsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportPriceListQuantityDiscountsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports quantity discounts data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportPriceListQuantityDiscountsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    #Do not import QunantityDiscounts from Base if Prepshop does not have PriceList feature
    if ($Shop->get('IsMigrationPrepShop') && !$Shop->featureMaxValue('PriceLists')) {
        return;
    }

    my $PriceListQuantityDiscountsHandler = __PACKAGE__->new($Shop);
    return $PriceListQuantityDiscountsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    my $Shop = $self->shop();
    my $PriceListQuantityDiscounts = GetPriceListQuantityDiscounts($Shop);
    return $PriceListQuantityDiscounts;

}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListQuantityDiscountsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::PriceListQuantityDiscountsExportDriver';
}

1;
