#========================================================================================
# package      DE_EPAGES::Zettle::API::Constants
# state        private
#----------------------------------------------------------------------------------------
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::Zettle::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    ZETTLE_ENVIRONMENT
    ALLOWED_EXPORT_INTERVALS
    APP_SCOPES
    API_PARTNER_ID
    API_MAX_NAME_LENGTH
    API_MAX_DESCRIPTION_LENGTH
    %INITIAL_EXPORT_STATUS
    VALIDATION_TOKEN_KEY
    ZETTLE_HOME_URL
);

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'Zettle';

# Name of the shop attribute which references the environment object
use constant ZETTLE_ENVIRONMENT => 'ZettleEnvironment';

# Valid export intervals for 'Update interval' selection in Scheduled Export section
use constant ALLOWED_EXPORT_INTERVALS => [ 1, 3, 7, 30 ];

# See "iZettle Partner Integrations: Solution Documentation" page 27, section 4.3.3. Permission Scopes
# Scope parameter: https://github.com/iZettle/api-documentation/blob/master/authorization.adoc#ask-the-user-to-authorize-the-client
use constant APP_SCOPES => qw(
    READ:USERINFO
    READ:PRODUCT
    WRITE:PRODUCT
);

# Identifier provided by Simona Pappalardo via email
use constant API_PARTNER_ID => 'epages';

use constant API_MAX_NAME_LENGTH => 256;
use constant API_MAX_DESCRIPTION_LENGTH => 1024;

our %INITIAL_EXPORT_STATUS = (
    'FAILED' => -1,
    'PENDING' => 0,
    'RUNNING' => 1,
    'COMPLETED' => 2,
);

use constant VALIDATION_TOKEN_KEY => 'ValidationToken';

use constant ZETTLE_HOME_URL => 'https://www.zettle.com';

1;
