#========================================================================================
# package      DE_EPAGES::Zettle::API::Object::ImageUploadResult
# state        public
#----------------------------------------------------------------------------------------
# description  class to store the result of image uploads to Zettle API.
#               Upload result has the following fields:
#               <ul>
#                   <li>epagesUrl - URL of product image under the shop domain - string
#                   <li>lookupKey - image lookup key which is the image identifier in Zettle Image service or undef if not available - string
#                   <li>zettleUrl - URL based in Zettle site where image is accesible or undef if not available - string
#                   <li>error - error description, if any error ocurred, or undef - string
#               </ul>
#========================================================================================
package DE_EPAGES::Zettle::API::Object::ImageUploadResult;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::Object::ImageUploadResult->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::Object::ImageUploadResult
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $EpagesUrl | URL of product image under the shop domain | string
sub epagesUrl {
    my $self = shift;
    my ($EpagesUrl) = @_;
    return $self->{'epagesUrl'} unless defined($EpagesUrl);
    $self->{'epagesUrl'} = $EpagesUrl;
}

# input        $LookupKey | image lookup key which is the image identifier in Zettle Image service or undef if not available | string
sub lookupKey {
    my $self = shift;
    my ($LookupKey) = @_;
    return $self->{'lookupKey'} unless defined($LookupKey);
    $self->{'lookupKey'} = $LookupKey;
}

# input        $ZettleUrl | URL based in Zettle site where image is accesible or undef if not available | string
sub zettleUrl {
    my $self = shift;
    my ($ZettleUrl) = @_;
    return $self->{'zettleUrl'} unless defined($ZettleUrl);
    $self->{'zettleUrl'} = $ZettleUrl;
}

# input        $Error | error description, if any error ocurred while uploading image, or undef if no error | string
sub error {
    my $self = shift;
    my ($Error) = @_;
    return $self->{'error'} unless defined($Error);
    $self->{'error'} = $Error;
}

1;
