#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to handle ImageUpload response
#               See Responses > Model > ImageUploadResponse in https://image.izettle.com/swagger#/images/uploadProductImage
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $ImageLookupKey | Image lookup key which matches image filename in Zettle (excluding extension) | string
sub imageLookupKey {
    my $self = shift;
    my ($ImageLookupKey) = @_;
    return $self->{'imageLookupKey'} unless defined($ImageLookupKey);
    $self->{'imageLookupKey'} = $ImageLookupKey;
}

# input        $aImageUrls | List of all image URLs generated in Zettle site associated to uploaded image.
#                             Original image is $aImageUrls[0] | ref.array.string
sub imageUrls {
    my $self = shift;
    my ($aImageUrls) = @_;
    return $self->{'imageUrls'} unless defined($aImageUrls);
    $self->{'imageUrls'} = $aImageUrls;
}

#========================================================================================
# function     parseResponse
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ImageUploadResponseDTO = DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO->parseResponse($hImageUploadResponse);
#----------------------------------------------------------------------------------------
# description  parse JSON contents from API ImageUpload response to produce a ImageUploadResponseDTO object
#----------------------------------------------------------------------------------------
# input        $hImageUploadResponse | JSON structure retrieved from API image query.
#                                       See Responses > Model > ImageUploadResponse in https://image.izettle.com/swagger#/images/uploadProductImage | string
#----------------------------------------------------------------------------------------
# return       $ImageUploadResponseDTO | a image upload response object | DE_EPAGES::Zettle::API::WebService::DTO::ImageUploadResponseDTO
#========================================================================================
sub parseResponse {
    my $class = shift;
    my ($hImageUploadResponse) = @_;

    my $ImageUploadResponseDTO = $class->new();
    $ImageUploadResponseDTO->imageLookupKey($hImageUploadResponse->{'imageLookupKey'});
    $ImageUploadResponseDTO->imageUrls($hImageUploadResponse->{'imageUrls'}) if defined $hImageUploadResponse->{'imageUrls'};

    return $ImageUploadResponseDTO;
}

1;
