#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class that wraps location response
#               See Responses > Model > location in https://inventory.izettle.com/swagger#/locations/getAllLocations
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

#========================================================================================
# function     uuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Uuid = $self->uuid();
# syntax       $self->uuid($Uuid);
#----------------------------------------------------------------------------------------
# description  Get/Set location UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Location UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $Uuid | Current location UUID if $Uuid parameter is not provided | string
#========================================================================================
sub uuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'uuid'} unless defined($Uuid);
    $self->{'uuid'} = $Uuid;
}

#========================================================================================
# function     type
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Type = $self->type();
# syntax       $self->type($Type);
#----------------------------------------------------------------------------------------
# description  Get/Set location type.
#               Type can be any of: SUPPLIER, STORE, SOLD, BIN
#----------------------------------------------------------------------------------------
# input        $Type | Location type | string
#----------------------------------------------------------------------------------------
# return       $Type | Current location type if $Type parameter is not provided | string
#========================================================================================
sub type {
    my $self = shift;
    my ($Type) = @_;
    return $self->{'type'} unless defined($Type);
    $self->{'type'} = $Type;
}

#========================================================================================
# function     name
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Name = $self->name();
# syntax       $self->name($Name);
#----------------------------------------------------------------------------------------
# description  Get/Set location name.
#----------------------------------------------------------------------------------------
# input        $Name | Name of location | string
#----------------------------------------------------------------------------------------
# return       $Name | Current location name if $Name parameter is not provided | string
#========================================================================================
sub name {
    my $self = shift;
    my ($Name) = @_;
    return $self->{'name'} unless defined($Name);
    $self->{'name'} = $Name;
}

#========================================================================================
# function     description
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Description = $self->description();
# syntax       $self->description($Description);
#----------------------------------------------------------------------------------------
# description  Get/Set location description.
#----------------------------------------------------------------------------------------
# input        $Description | Location description | string
#----------------------------------------------------------------------------------------
# return       $Description | Current location description if $Description parameter is not provided | string
#========================================================================================
sub description {
    my $self = shift;
    my ($Description) = @_;
    return $self->{'description'} unless defined($Description);
    $self->{'description'} = $Description;
}

#========================================================================================
# function     default
# state        public
#----------------------------------------------------------------------------------------
# syntax       $IsDefault = $self->default();
# syntax       $self->default($IsDefault);
#----------------------------------------------------------------------------------------
# description  Get/Set location default status.
#----------------------------------------------------------------------------------------
# input        $IsDefault | Location default status | boolean
#----------------------------------------------------------------------------------------
# return       $IsDefault | Current location default status if $IsDefault parameter is not provided. TRUE if location is the default one, false otherwise. | boolean
#========================================================================================
sub default {
    my $self = shift;
    my ($IsDefault) = @_;
    return $self->{'default'} unless defined($IsDefault);
    $self->{'default'} = $IsDefault;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LocationDTO = DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO->fromHash($hLocation);
#----------------------------------------------------------------------------------------
# description  Parse location info and return a LocationDTO object.
#               See Responses > Model > location in https://inventory.izettle.com/swagger#/locations/getAllLocations
#----------------------------------------------------------------------------------------
# input        $hLocation | Location data with following keys:
#               <ul>
#                   <li>uuid - location UUID - string
#                   <li>type - type of location, any of: SUPPLIER, STORE, SOLD, BIN - string
#                   <li>name - name of location - string
#                   <li>description - description of location - string
#                   <li>default - location default status. TRUE if location is the default one - boolean
#               </ul> | ref.hash
#----------------------------------------------------------------------------------------
# return       $LocationDTO | a LocationDTO object | DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
#========================================================================================
sub fromHash {
    my $class = shift;
    my ($hLocation) = @_;

    my $LocationDTO = $class->new();
    $LocationDTO->uuid($hLocation->{'uuid'});
    $LocationDTO->type($hLocation->{'type'});
    $LocationDTO->name($hLocation->{'name'});
    $LocationDTO->description($hLocation->{'description'});
    $LocationDTO->default($hLocation->{'default'} eq 'true' ? 1 : 0);

    return $LocationDTO;
}

1;
