#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to handle webhooks event subscription response
#               See Responses > Model > SubscriptionResponse in https://pusher.izettle.com/swagger#/subscriptions/createSubscription
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO;

use strict;

use DE_EPAGES::Zettle::API::Tools qw ( ParseDateTime );

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $Uuid | Identifies the subscription | string
sub uuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'uuid'} unless defined($Uuid);
    $self->{'uuid'} = $Uuid;
}

# input        $TransportName | Type of transport, any of: WEBHOOK, SQS | string
sub transportName {
    my $self = shift;
    my ($TransportName) = @_;
    return $self->{'transportName'} unless defined($TransportName);
    $self->{'transportName'} = $TransportName;
}

# input        $aEventNames | List of event names | ref.array.string
sub eventNames {
    my $self = shift;
    my ($aEventNames) = @_;
    return $self->{'eventNames'} unless defined($aEventNames);
    $self->{'eventNames'} = $aEventNames;
}

# input        $Updated | Timestamp when last updated | Datetime
sub updated {
    my $self = shift;
    my ($Updated) = @_;
    return $self->{'updated'} unless defined($Updated);
    $self->{'updated'} = $Updated;
}

# input        $Destination | Callback URL where events will be pushed | string
sub destination {
    my $self = shift;
    my ($Destination) = @_;
    return $self->{'destination'} unless defined($Destination);
    $self->{'destination'} = $Destination;
}

# input        $ContactEmail | Contact email for the subscription, automatic email will be sent if endpoint fails | string
sub contactEmail {
    my $self = shift;
    my ($ContactEmail) = @_;
    return $self->{'contactEmail'} unless defined($ContactEmail);
    $self->{'contactEmail'} = $ContactEmail;
}

# input        $Status | Status of subscription, any of: ACTIVE, FAILING | string
sub status {
    my $self = shift;
    my ($Status) = @_;
    return $self->{'status'} unless defined($Status);
    $self->{'status'} = $Status;
}

# input        $SigningKey | The HMACSHA256 key used to sign the webhook payload | string
sub signingKey {
    my $self = shift;
    my ($SigningKey) = @_;
    return $self->{'signingKey'} unless defined($SigningKey);
    $self->{'signingKey'} = $SigningKey;
}

# input        $ClientId | Client UUID | string
sub clientId {
    my $self = shift;
    my ($ClientId) = @_;
    return $self->{'clientId'} unless defined($ClientId);
    $self->{'clientId'} = $ClientId;
}

#========================================================================================
# function     parseResponse
# state        public
#----------------------------------------------------------------------------------------
# syntax       $SubscriptionResponseDTO = DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO->parseResponse($hSubscriptionResponse);
#----------------------------------------------------------------------------------------
# description  parse JSON contents from Pusher API subscription response to produce a SubscriptionResponseDTO object
#----------------------------------------------------------------------------------------
# input        $hSubscriptionResponse | JSON structure retrieved from subscription request.
#                                        See Responses > Model > SubscriptionResponse in https://pusher.izettle.com/swagger#/subscriptions/createSubscription | string
#----------------------------------------------------------------------------------------
# return       $SubscriptionResponseDTO | a subscription response object | DE_EPAGES::Zettle::API::WebService::DTO::SubscriptionResponseDTO
#========================================================================================
sub parseResponse {
    my $class = shift;
    my ($hSubscriptionResponse) = @_;

    my $SubscriptionResponseDTO = $class->new();
    $SubscriptionResponseDTO->uuid($hSubscriptionResponse->{'uuid'});
    $SubscriptionResponseDTO->transportName($hSubscriptionResponse->{'transportName'});
    $SubscriptionResponseDTO->eventNames($hSubscriptionResponse->{'eventNames'});
    my $UpdatedDt = ParseDateTime($hSubscriptionResponse->{'updated'});
    $SubscriptionResponseDTO->updated($UpdatedDt);
    $SubscriptionResponseDTO->destination($hSubscriptionResponse->{'destination'});
    $SubscriptionResponseDTO->contactEmail($hSubscriptionResponse->{'contactEmail'}) if defined $hSubscriptionResponse->{'contactEmail'};
    $SubscriptionResponseDTO->status($hSubscriptionResponse->{'status'});
    $SubscriptionResponseDTO->signingKey($hSubscriptionResponse->{'signingKey'});
    $SubscriptionResponseDTO->clientId($hSubscriptionResponse->{'clientId'}) if defined $hSubscriptionResponse->{'clientId'};

    return $SubscriptionResponseDTO;
}

1;
