#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class that wraps variation balance response
#               See Responses > Model > locationInventory > variants > locationBalance in https://inventory.izettle.com/swagger#/inventory/getInventoryByLocationType
#               See Responses > Model > locationInventory > variants > locationBalance in https://inventory.izettle.com/swagger#/inventory/getInventoryForLocation
#               See Responses > Model > productBalance > variants > locationBalance in https://inventory.izettle.com/swagger#/inventory/getInventoryForProduct
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

#========================================================================================
# function     locationUuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LocationUuid = $self->locationUuid();
# syntax       $self->locationUuid($UUID);
#----------------------------------------------------------------------------------------
# description  Get/Set location UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Location UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $LocationUuid | Current location UUID if $Uuid parameter is not provided | string
#========================================================================================
sub locationUuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'locationUuid'} unless defined($Uuid);
    $self->{'locationUuid'} = $Uuid;
}

#========================================================================================
# function     locationType
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LocationType = $self->locationType();
# syntax       $self->locationType($Type);
#----------------------------------------------------------------------------------------
# description  Get/Set location type.
#----------------------------------------------------------------------------------------
# input        $Type | Type of location, any of: SUPPLIER, STORE, SOLD, BIN | string
#----------------------------------------------------------------------------------------
# return       $LocationType | Current location type if $Type parameter is not provided | string
#========================================================================================
sub locationType {
    my $self = shift;
    my ($Type) = @_;
    return $self->{'locationType'} unless defined($Type);
    $self->{'locationType'} = $Type;
}

#========================================================================================
# function     productUuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ProductUuid = $self->productUuid();
# syntax       $self->productUuid($Uuid);
#----------------------------------------------------------------------------------------
# description  Get/Set product UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Product UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $ProductUuid | Current product UUID if $Uuid parameter is not provided | string
#========================================================================================
sub productUuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'productUuid'} unless defined($Uuid);
    $self->{'productUuid'} = $Uuid;
}

#========================================================================================
# function     variationUuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $VariationUuid = $self->variationUuid();
# syntax       $self->variationUuid($Uuid);
#----------------------------------------------------------------------------------------
# description  Get/Set variation UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Variation UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $VariationUuid | Current variation UUID if $Uuid parameter is not provided | string
#========================================================================================
sub variationUuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'variantUuid'} unless defined($Uuid);
    $self->{'variantUuid'} = $Uuid;
}

#========================================================================================
# function     balance
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Balance = $self->balance();
# syntax       $self->balance($Balance);
#----------------------------------------------------------------------------------------
# description  Get/Set variation balance.
#----------------------------------------------------------------------------------------
# input        $Balance | Variation balance | string
#----------------------------------------------------------------------------------------
# return       $Balance | Current variation balance if $Balance parameter is not provided | string
#========================================================================================
sub balance {
    my $self = shift;
    my ($Balance) = @_;
    return $self->{'balance'} unless defined($Balance);
    $self->{'balance'} = $Balance;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $VariationBalanceDTO = DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO->fromHash($hLocationBalance);
#----------------------------------------------------------------------------------------
# description  Parse location balance info and return a VariationBalanceDTO object.
#----------------------------------------------------------------------------------------
# input        $hLocationBalance | Location balance as part of ProductInventory API response with following keys:
#               <ul>
#                   <li>locationUuid - location UUID - string
#                   <li>locationType - type of location [ SUPPLIER, STORE, SOLD, BIN ] - string
#                   <li>productUuid - super product UUID - string
#                   <li>variantUuid - variation UUID - string
#                   <li>balance - stock level - string
#               </ul> | ref.hash
#----------------------------------------------------------------------------------------
# return       $VariationBalanceDTO | a VariationBalanceDTO object | DE_EPAGES::Zettle::API::WebService::DTO::VariationBalanceDTO
#========================================================================================
sub fromHash {
    my $class = shift;
    my ($hLocationBalance) = @_;

    my $VariationBalanceDTO = $class->new();
    $VariationBalanceDTO->locationUuid($hLocationBalance->{'locationUuid'});
    $VariationBalanceDTO->locationType($hLocationBalance->{'locationType'});
    $VariationBalanceDTO->productUuid($hLocationBalance->{'productUuid'});
    $VariationBalanceDTO->variationUuid($hLocationBalance->{'variantUuid'});
    $VariationBalanceDTO->balance($hLocationBalance->{'balance'});

    return $VariationBalanceDTO;
}

1;
