#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::LocationService
# base         DE_EPAGES::Zettle::API::WebService::RestService
# state        private
#----------------------------------------------------------------------------------------
# description  Service wrapper around location-related methods from Zettle Inventory API.
#               See DE_EPAGES/Zettle/Documents/API/ZettlePartnerDocumentation-Extracts.md, section 4.7.1. Inventory Lifecycle and Locations
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::LocationService;
use base DE_EPAGES::Zettle::API::WebService::RestService;

use strict;

use DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO;
use DE_EPAGES::Zettle::API::WebService::EndpointHandler qw ( GetAllLocationsApiUrl );

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::LocationService->new($Environment);
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# input        $Environment | a Zettle environment object | DE_EPAGES::Zettle::API::Object:ZettleEnvironment
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::LocationService
#========================================================================================
sub new {
    my $class = shift;
    my ($Environment) = @_;

    my $self = $class->SUPER::new($Environment);
    return $self;
}

#========================================================================================
# function     getAllLocations
# state        public
#----------------------------------------------------------------------------------------
# syntax       $aLocationDTO = $self->getAllLocations();
#----------------------------------------------------------------------------------------
# description  Retrieve all locations from Zettle.
#               See: https://inventory.izettle.com/swagger#/locations/getAllLocations
#----------------------------------------------------------------------------------------
# return       $aLocationDTO | List of locations.
#                               See DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO | ref.array.object
#========================================================================================
sub getAllLocations {
    my $self = shift;

    my $LocationsUrl = GetAllLocationsApiUrl();

    my $HttpResponse = $self->sendGetRequest($LocationsUrl);
    my $ahLocation = $self->decodeResponseContent($HttpResponse);

    my @aLocationDTO;
    foreach my $hLocation (@{$ahLocation}){
        my $LocationDTO = DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO->fromHash($hLocation);
        push(@aLocationDTO, $LocationDTO);
    }

    return \@aLocationDTO;
}

1;
