# CONTENTS
This document contains extracts of interest from Zettle API documentation, which consists in several
HTML pages and Swagger docs.
The documentation comprises all available Zettle endpoints but the main document can be found here:
[iZettle public API documentation](https://github.com/iZettle/api-documentation)

Each of the endpoints has it's own section and also a Swagger documentation with details regarding
API methods and data models:
1. Authorization:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/authorization.adoc)
2. Finance:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/finance.adoc)
3. Giftcard:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/giftcard.adoc)
4. Image:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/image.adoc)
    2. [Swagger](https://image.izettle.com/swagger)
5. Inventory: https://github.com/iZettle/api-documentation/blob/master/inventory.adoc
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/inventory.adoc)
    2. [Swagger](https://inventory.izettle.com/swagger)
6. Products: https://github.com/iZettle/api-documentation/blob/master/product-library.adoc
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/product-library.adoc)
    2. [Swagger](https://products.izettle.com/swagger)
7. Purchase:
    1. [Github DOC](https://github.com/iZettle/api-documentation/blob/master/purchase.adoc)

# EXTRACTS

## 4.2.1.2. Sample BulkProductImageUpload response
In `DE_EPAGES::Zettle::API::WebService::ImageService::bulkUploadImages` method we upload images to Zettle.
The response model is specified in *Responses > Model > BulkImageUploadResponse*
in  [Bulk product image upload](https://image.izettle.com/swagger#/images/uploadProductImageBulk).

Below is a sample response:
```
{
    'uploaded' => [
        {
            'source' => 'https://epnow-01.upango.es/WebRoot/Store/Shops/zettle-gb/60D6/5943/7F69/9FB7/B4CB/B976/395F/7FC6/frame.jpg',
            'imageLookupKey' => 'GlLiqIJNEeusyKr6Jki1nw-YKWnhgKXEeyEogOnBds16g',
            'imageUrls' => [
                'https://image.izettle.com/product/GlLiqIJNEeusyKr6Jki1nw-YKWnhgKXEeyEogOnBds16g.jpeg'
            ]
        },
        {
            'source' => 'https://epages.com/wp-content/uploads/2018/10/start-page-demoshop-en-6.jpg',
            'imageLookupKey' => 'GlLiqIJNEeusyKr6Jki1nw-YKWpbgKXEeyWKpedX5Vo1Q',
            'imageUrls' => [
                'https://image.izettle.com/product/GlLiqIJNEeusyKr6Jki1nw-YKWpbgKXEeyWKpedX5Vo1Q.jpeg'
            ]
        }
    ],
    'invalid' => [
        'http://bs927.serverbs.com/WebRoot/StorePIM/Shops/PimShop/Products/demo1/demo1.jpg',
        'http://bs927.serverbs.com/WebRoot/StorePIM/Shops/PimShop/Products/demo2/demo2.jpg'
    ]
};
```

## 6.2.3.3. Unused ProductDTO fields
When creating product DTO for exporting to Zettle, there are a number of fields/methods that are
unused for the moment but may be useful in the future.
See method `DE_EPAGES::Zettle::API::WebService::DTO::DTOFactory::buildProductDTO`.

The list of fields present in Zettle model but unused is:
- $ProductDTO->online($Online);
- $ProductDTO->categories($MainCategory);
- $ProductDTO->presentation($ProductPresentation);
- $ProductDTO->taxCode($TaxCode);
- $ProductDTO->category($Category);
- $ProductDTO->taxRates($TaxRates);
- $ProductDTO->taxExempt($TaxExempt);

For more details regarding API see *Request body > Schema > BulkImportRequest > FullProductUpdateRequest*
in  [Bulk product import](https://products.izettle.com/swagger#/import/importLibraryV2).