#========================================================================================
# package      DE_EPAGES::Zettle::t::unit::LocationInventoryDTO
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Zettle::t::unit::LocationInventoryDTO
#========================================================================================
package DE_EPAGES::Zettle::t::unit::LocationInventoryDTO;
use base DE_EPAGES::Core::API::Test;

use strict;

use DE_EPAGES::Zettle::API::WebService::DTO::LocationInventoryDTO;

use Test::More;

use constant LOCATION_UUID => '16fcb092-a42c-4b72-8625-41fb168ca355';
use constant LOCATION_TYPE => 'SUPPLIER';
use constant PRODUCT1_UUID  => 'fe461ad3-90e8-4304-8be9-91edb12854f0';
use constant PRODUCT2_UUID  => 'a8e04ff7-768b-44a6-99c3-727d047e59c2';
use constant VARIATION1_UUID  => '3fa85f64-5717-4562-b3fc-2c963f66afa6';
use constant VARIATION2_UUID  => '256da9d7-e1a9-435b-a868-c768112b901b';
use constant BALANCE1       => '17';
use constant BALANCE2       => '32';
use constant LATEST       => '0';

use constant TRACKED_PRODUCTS => [
    PRODUCT1_UUID,
    PRODUCT2_UUID
];
use constant VARIANTS => [
    {
        'locationUuid' => LOCATION_UUID,
        'locationType' => LOCATION_TYPE,
        'productUuid'  => PRODUCT1_UUID,
        'variantUuid'  => VARIATION1_UUID,
        'balance'      => BALANCE1
    },
    {
        'locationUuid' => LOCATION_UUID,
        'locationType' => LOCATION_TYPE,
        'productUuid'  => PRODUCT2_UUID,
        'variantUuid'  => VARIATION2_UUID,
        'balance'      => BALANCE2
    }
];

sub test {
    my $self = shift;

    $self->test_fromHash();

    done_testing();
}

sub test_fromHash {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hLocationInventory = $self->_generateLocationInventory();
    my $DTO = DE_EPAGES::Zettle::API::WebService::DTO::LocationInventoryDTO->fromHash($hLocationInventory);
    
    is(
        $DTO->locationUuid(),
        LOCATION_UUID,
        "$SubTestName - locationUuid"
    );
    is_deeply(
        $DTO->products(),
        TRACKED_PRODUCTS,
        "$SubTestName - products"
    );    
    is_deeply(
        $DTO->variationBalances(),
        VARIANTS,
        "$SubTestName - variationBalances"
    );
    is(
        $DTO->latest(),
        LATEST,
        "$SubTestName - latest"
    );
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------

sub _generateLocationInventory {
    my $self = shift;

    return {
        'locationUuid' => LOCATION_UUID,
        'trackedProducts' => TRACKED_PRODUCTS,
        'variants' => VARIANTS,
        'latest' => LATEST
    };
}

#========================================================================================
# Main
#========================================================================================

__PACKAGE__->runScript();